pub fn validate_block_access_list_presence<T: EthereumHardforks>( chain_spec: &T, version: EngineApiMessageVersion, message_validation_kind: MessageValidationKind, timestamp: u64, has_block_access_list: bool, ) -> Result<(), EngineObjectValidationError>
Validates the presence of the block access lists field according to the payload timestamp. After Amsterdam, block access list field must be Some. Before Amsterdam, block access list field must be None;
block access lists